[gvfs] Add more translation context
- From: Kjartan Maraas <kmaraas src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gvfs] Add more translation context
- Date: Tue, 24 May 2011 07:23:30 +0000 (UTC)
commit 79ec8a37c1052efbc2691a3d2aa1cce3fa838e76
Author: Kjartan Maraas <kmaraas gnome org>
Date: Tue May 24 09:23:05 2011 +0200
Add more translation context
daemon/gvfsbackendcdda.c | 3 ++-
daemon/gvfsbackendgphoto2.c | 3 ++-
2 files changed, 4 insertions(+), 2 deletions(-)
---
diff --git a/daemon/gvfsbackendgphoto2.c b/daemon/gvfsbackendgphoto2.c
index 1182748..1f18788 100644
--- a/daemon/gvfsbackendgphoto2.c
+++ b/daemon/gvfsbackendgphoto2.c
@@ -1679,7 +1679,8 @@ do_mount (GVfsBackend *backend,
return;
}
- /* Translator: %s represents the device, e.g. usb:001,042 */
+ /* Translator: %s represents the device, e.g. usb:001,042. 'gphoto2' is the name of the
+ backend and shouldn't be translated. */
fuse_name = g_strdup_printf (_("gphoto2 mount on %s"), gphoto2_backend->gphoto2_port);
icon_name = compute_icon_name (gphoto2_backend);
display_name = compute_display_name (gphoto2_backend);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/daemon/gvfsbackendcdda.c b/daemon/gvfsbackendcdda.c
index e7228ac..6f009c7 100644
--- a/daemon/gvfsbackendcdda.c
+++ b/daemon/gvfsbackendcdda.c
@@ -435,7 +435,8 @@ do_mount (GVfsBackend *backend,
return;
}
- /* Translator: %s is the device the disc is inserted into */
+ /* Translator: %s is the device the disc is inserted into. 'cdda' is the name
+ name of the backend and shouldn't be translated. */
fuse_name = g_strdup_printf (_("cdda mount on %s"), host);
display_name = g_strdup_printf (_("Audio Disc"));
g_vfs_backend_set_stable_name (backend, fuse_name);